# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKLevelSetsPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkSparseFieldFourthOrderLevelSetImageFilterPython
else:
    import _itkSparseFieldFourthOrderLevelSetImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrix_fixedPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.itkPointPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkVectorPython
import itk.itkCovariantVectorPython
import itk.itkSparseFieldLevelSetImageFilterPython
import itk.itkFiniteDifferenceImageFilterPython
import itk.itkInPlaceImageFilterAPython
import itk.itkImageToImageFilterBPython
import itk.itkImageRegionPython
import itk.itkSizePython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkImageSourcePython
import itk.itkImagePython
import itk.itkRGBPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBAPixelPython
import itk.itkImageSourceCommonPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageToImageFilterAPython
import itk.itkFiniteDifferenceFunctionPython
import itk.itkLevelSetFunctionPython
class vectoritkImageNBNIF22(collections.abc.MutableSequence if _swig_python_version_info >= (3, 3) else collections.MutableSequence):
    r"""Proxy of C++ std::vector< itkImageNBNIF22_Pointer > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        r"""iterator(self) -> SwigPyIterator"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        r"""__nonzero__(self) -> bool"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22___nonzero__(self)

    def __bool__(self):
        r"""__bool__(self) -> bool"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22___bool__(self)

    def __len__(self):
        r"""__len__(self) -> std::vector< itkImageNBNIF22_Pointer >::size_type"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22___len__(self)

    def __getslice__(self, i, j):
        r"""
        __getslice__(self, i, j) -> vectoritkImageNBNIF22

        Parameters
        ----------
        i: std::vector< itkImageNBNIF22_Pointer >::difference_type
        j: std::vector< itkImageNBNIF22_Pointer >::difference_type

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22___getslice__(self, i, j)

    def __setslice__(self, *args):
        r"""
        __setslice__(self, i, j)

        Parameters
        ----------
        i: std::vector< itkImageNBNIF22_Pointer >::difference_type
        j: std::vector< itkImageNBNIF22_Pointer >::difference_type

        __setslice__(self, i, j, v)

        Parameters
        ----------
        i: std::vector< itkImageNBNIF22_Pointer >::difference_type
        j: std::vector< itkImageNBNIF22_Pointer >::difference_type
        v: std::vector< itkImageNBNIF22_Pointer,std::allocator< itkImageNBNIF22_Pointer > > const &

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22___setslice__(self, *args)

    def __delslice__(self, i, j):
        r"""
        __delslice__(self, i, j)

        Parameters
        ----------
        i: std::vector< itkImageNBNIF22_Pointer >::difference_type
        j: std::vector< itkImageNBNIF22_Pointer >::difference_type

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22___delslice__(self, i, j)

    def __delitem__(self, *args):
        r"""
        __delitem__(self, i)

        Parameters
        ----------
        i: std::vector< itkImageNBNIF22_Pointer >::difference_type

        __delitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22___delitem__(self, *args)

    def __getitem__(self, *args):
        r"""
        __getitem__(self, slice) -> vectoritkImageNBNIF22

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __getitem__(self, i) -> std::vector< itkImageNBNIF22_Pointer >::value_type const &

        Parameters
        ----------
        i: std::vector< itkImageNBNIF22_Pointer >::difference_type

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22___getitem__(self, *args)

    def __setitem__(self, *args):
        r"""
        __setitem__(self, slice, v)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *
        v: std::vector< itkImageNBNIF22_Pointer,std::allocator< itkImageNBNIF22_Pointer > > const &

        __setitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __setitem__(self, i, x)

        Parameters
        ----------
        i: std::vector< itkImageNBNIF22_Pointer >::difference_type
        x: std::vector< itkImageNBNIF22_Pointer >::value_type const &

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22___setitem__(self, *args)

    def pop(self):
        r"""pop(self) -> std::vector< itkImageNBNIF22_Pointer >::value_type"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22_pop(self)

    def append(self, x):
        r"""
        append(self, x)

        Parameters
        ----------
        x: std::vector< itkImageNBNIF22_Pointer >::value_type const &

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22_append(self, x)

    def empty(self):
        r"""empty(self) -> bool"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22_empty(self)

    def size(self):
        r"""size(self) -> std::vector< itkImageNBNIF22_Pointer >::size_type"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22_size(self)

    def swap(self, v):
        r"""
        swap(self, v)

        Parameters
        ----------
        v: std::vector< itkImageNBNIF22_Pointer > &

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22_swap(self, v)

    def begin(self):
        r"""begin(self) -> std::vector< itkImageNBNIF22_Pointer >::iterator"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22_begin(self)

    def end(self):
        r"""end(self) -> std::vector< itkImageNBNIF22_Pointer >::iterator"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22_end(self)

    def rbegin(self):
        r"""rbegin(self) -> std::vector< itkImageNBNIF22_Pointer >::reverse_iterator"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22_rbegin(self)

    def rend(self):
        r"""rend(self) -> std::vector< itkImageNBNIF22_Pointer >::reverse_iterator"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22_rend(self)

    def clear(self):
        r"""clear(self)"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22_clear(self)

    def get_allocator(self):
        r"""get_allocator(self) -> std::vector< itkImageNBNIF22_Pointer >::allocator_type"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22_get_allocator(self)

    def pop_back(self):
        r"""pop_back(self)"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22_pop_back(self)

    def erase(self, *args):
        r"""
        erase(self, pos) -> std::vector< itkImageNBNIF22_Pointer >::iterator

        Parameters
        ----------
        pos: std::vector< itkImageNBNIF22_Pointer >::iterator

        erase(self, first, last) -> std::vector< itkImageNBNIF22_Pointer >::iterator

        Parameters
        ----------
        first: std::vector< itkImageNBNIF22_Pointer >::iterator
        last: std::vector< itkImageNBNIF22_Pointer >::iterator

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22_erase(self, *args)

    def __init__(self, *args):
        r"""
        __init__(self) -> vectoritkImageNBNIF22
        __init__(self, other) -> vectoritkImageNBNIF22

        Parameters
        ----------
        other: std::vector< itkImageNBNIF22_Pointer > const &

        __init__(self, size) -> vectoritkImageNBNIF22

        Parameters
        ----------
        size: std::vector< itkImageNBNIF22_Pointer >::size_type

        __init__(self, size, value) -> vectoritkImageNBNIF22

        Parameters
        ----------
        size: std::vector< itkImageNBNIF22_Pointer >::size_type
        value: std::vector< itkImageNBNIF22_Pointer >::value_type const &

        """
        _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22_swiginit(self, _itkSparseFieldFourthOrderLevelSetImageFilterPython.new_vectoritkImageNBNIF22(*args))

    def push_back(self, x):
        r"""
        push_back(self, x)

        Parameters
        ----------
        x: std::vector< itkImageNBNIF22_Pointer >::value_type const &

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22_push_back(self, x)

    def front(self):
        r"""front(self) -> std::vector< itkImageNBNIF22_Pointer >::value_type const &"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22_front(self)

    def back(self):
        r"""back(self) -> std::vector< itkImageNBNIF22_Pointer >::value_type const &"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22_back(self)

    def assign(self, n, x):
        r"""
        assign(self, n, x)

        Parameters
        ----------
        n: std::vector< itkImageNBNIF22_Pointer >::size_type
        x: std::vector< itkImageNBNIF22_Pointer >::value_type const &

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22_assign(self, n, x)

    def resize(self, *args):
        r"""
        resize(self, new_size)

        Parameters
        ----------
        new_size: std::vector< itkImageNBNIF22_Pointer >::size_type

        resize(self, new_size, x)

        Parameters
        ----------
        new_size: std::vector< itkImageNBNIF22_Pointer >::size_type
        x: std::vector< itkImageNBNIF22_Pointer >::value_type const &

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22_resize(self, *args)

    def insert(self, *args):
        r"""
        insert(self, pos, x) -> std::vector< itkImageNBNIF22_Pointer >::iterator

        Parameters
        ----------
        pos: std::vector< itkImageNBNIF22_Pointer >::iterator
        x: std::vector< itkImageNBNIF22_Pointer >::value_type const &

        insert(self, pos, n, x)

        Parameters
        ----------
        pos: std::vector< itkImageNBNIF22_Pointer >::iterator
        n: std::vector< itkImageNBNIF22_Pointer >::size_type
        x: std::vector< itkImageNBNIF22_Pointer >::value_type const &

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22_insert(self, *args)

    def reserve(self, n):
        r"""
        reserve(self, n)

        Parameters
        ----------
        n: std::vector< itkImageNBNIF22_Pointer >::size_type

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22_reserve(self, n)

    def capacity(self):
        r"""capacity(self) -> std::vector< itkImageNBNIF22_Pointer >::size_type"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22_capacity(self)
    __swig_destroy__ = _itkSparseFieldFourthOrderLevelSetImageFilterPython.delete_vectoritkImageNBNIF22

# Register vectoritkImageNBNIF22 in _itkSparseFieldFourthOrderLevelSetImageFilterPython:
_itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF22_swigregister(vectoritkImageNBNIF22)
class vectoritkImageNBNIF33(collections.abc.MutableSequence if _swig_python_version_info >= (3, 3) else collections.MutableSequence):
    r"""Proxy of C++ std::vector< itkImageNBNIF33_Pointer > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        r"""iterator(self) -> SwigPyIterator"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        r"""__nonzero__(self) -> bool"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33___nonzero__(self)

    def __bool__(self):
        r"""__bool__(self) -> bool"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33___bool__(self)

    def __len__(self):
        r"""__len__(self) -> std::vector< itkImageNBNIF33_Pointer >::size_type"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33___len__(self)

    def __getslice__(self, i, j):
        r"""
        __getslice__(self, i, j) -> vectoritkImageNBNIF33

        Parameters
        ----------
        i: std::vector< itkImageNBNIF33_Pointer >::difference_type
        j: std::vector< itkImageNBNIF33_Pointer >::difference_type

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33___getslice__(self, i, j)

    def __setslice__(self, *args):
        r"""
        __setslice__(self, i, j)

        Parameters
        ----------
        i: std::vector< itkImageNBNIF33_Pointer >::difference_type
        j: std::vector< itkImageNBNIF33_Pointer >::difference_type

        __setslice__(self, i, j, v)

        Parameters
        ----------
        i: std::vector< itkImageNBNIF33_Pointer >::difference_type
        j: std::vector< itkImageNBNIF33_Pointer >::difference_type
        v: std::vector< itkImageNBNIF33_Pointer,std::allocator< itkImageNBNIF33_Pointer > > const &

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33___setslice__(self, *args)

    def __delslice__(self, i, j):
        r"""
        __delslice__(self, i, j)

        Parameters
        ----------
        i: std::vector< itkImageNBNIF33_Pointer >::difference_type
        j: std::vector< itkImageNBNIF33_Pointer >::difference_type

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33___delslice__(self, i, j)

    def __delitem__(self, *args):
        r"""
        __delitem__(self, i)

        Parameters
        ----------
        i: std::vector< itkImageNBNIF33_Pointer >::difference_type

        __delitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33___delitem__(self, *args)

    def __getitem__(self, *args):
        r"""
        __getitem__(self, slice) -> vectoritkImageNBNIF33

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __getitem__(self, i) -> std::vector< itkImageNBNIF33_Pointer >::value_type const &

        Parameters
        ----------
        i: std::vector< itkImageNBNIF33_Pointer >::difference_type

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33___getitem__(self, *args)

    def __setitem__(self, *args):
        r"""
        __setitem__(self, slice, v)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *
        v: std::vector< itkImageNBNIF33_Pointer,std::allocator< itkImageNBNIF33_Pointer > > const &

        __setitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __setitem__(self, i, x)

        Parameters
        ----------
        i: std::vector< itkImageNBNIF33_Pointer >::difference_type
        x: std::vector< itkImageNBNIF33_Pointer >::value_type const &

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33___setitem__(self, *args)

    def pop(self):
        r"""pop(self) -> std::vector< itkImageNBNIF33_Pointer >::value_type"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33_pop(self)

    def append(self, x):
        r"""
        append(self, x)

        Parameters
        ----------
        x: std::vector< itkImageNBNIF33_Pointer >::value_type const &

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33_append(self, x)

    def empty(self):
        r"""empty(self) -> bool"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33_empty(self)

    def size(self):
        r"""size(self) -> std::vector< itkImageNBNIF33_Pointer >::size_type"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33_size(self)

    def swap(self, v):
        r"""
        swap(self, v)

        Parameters
        ----------
        v: std::vector< itkImageNBNIF33_Pointer > &

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33_swap(self, v)

    def begin(self):
        r"""begin(self) -> std::vector< itkImageNBNIF33_Pointer >::iterator"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33_begin(self)

    def end(self):
        r"""end(self) -> std::vector< itkImageNBNIF33_Pointer >::iterator"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33_end(self)

    def rbegin(self):
        r"""rbegin(self) -> std::vector< itkImageNBNIF33_Pointer >::reverse_iterator"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33_rbegin(self)

    def rend(self):
        r"""rend(self) -> std::vector< itkImageNBNIF33_Pointer >::reverse_iterator"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33_rend(self)

    def clear(self):
        r"""clear(self)"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33_clear(self)

    def get_allocator(self):
        r"""get_allocator(self) -> std::vector< itkImageNBNIF33_Pointer >::allocator_type"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33_get_allocator(self)

    def pop_back(self):
        r"""pop_back(self)"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33_pop_back(self)

    def erase(self, *args):
        r"""
        erase(self, pos) -> std::vector< itkImageNBNIF33_Pointer >::iterator

        Parameters
        ----------
        pos: std::vector< itkImageNBNIF33_Pointer >::iterator

        erase(self, first, last) -> std::vector< itkImageNBNIF33_Pointer >::iterator

        Parameters
        ----------
        first: std::vector< itkImageNBNIF33_Pointer >::iterator
        last: std::vector< itkImageNBNIF33_Pointer >::iterator

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33_erase(self, *args)

    def __init__(self, *args):
        r"""
        __init__(self) -> vectoritkImageNBNIF33
        __init__(self, other) -> vectoritkImageNBNIF33

        Parameters
        ----------
        other: std::vector< itkImageNBNIF33_Pointer > const &

        __init__(self, size) -> vectoritkImageNBNIF33

        Parameters
        ----------
        size: std::vector< itkImageNBNIF33_Pointer >::size_type

        __init__(self, size, value) -> vectoritkImageNBNIF33

        Parameters
        ----------
        size: std::vector< itkImageNBNIF33_Pointer >::size_type
        value: std::vector< itkImageNBNIF33_Pointer >::value_type const &

        """
        _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33_swiginit(self, _itkSparseFieldFourthOrderLevelSetImageFilterPython.new_vectoritkImageNBNIF33(*args))

    def push_back(self, x):
        r"""
        push_back(self, x)

        Parameters
        ----------
        x: std::vector< itkImageNBNIF33_Pointer >::value_type const &

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33_push_back(self, x)

    def front(self):
        r"""front(self) -> std::vector< itkImageNBNIF33_Pointer >::value_type const &"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33_front(self)

    def back(self):
        r"""back(self) -> std::vector< itkImageNBNIF33_Pointer >::value_type const &"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33_back(self)

    def assign(self, n, x):
        r"""
        assign(self, n, x)

        Parameters
        ----------
        n: std::vector< itkImageNBNIF33_Pointer >::size_type
        x: std::vector< itkImageNBNIF33_Pointer >::value_type const &

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33_assign(self, n, x)

    def resize(self, *args):
        r"""
        resize(self, new_size)

        Parameters
        ----------
        new_size: std::vector< itkImageNBNIF33_Pointer >::size_type

        resize(self, new_size, x)

        Parameters
        ----------
        new_size: std::vector< itkImageNBNIF33_Pointer >::size_type
        x: std::vector< itkImageNBNIF33_Pointer >::value_type const &

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33_resize(self, *args)

    def insert(self, *args):
        r"""
        insert(self, pos, x) -> std::vector< itkImageNBNIF33_Pointer >::iterator

        Parameters
        ----------
        pos: std::vector< itkImageNBNIF33_Pointer >::iterator
        x: std::vector< itkImageNBNIF33_Pointer >::value_type const &

        insert(self, pos, n, x)

        Parameters
        ----------
        pos: std::vector< itkImageNBNIF33_Pointer >::iterator
        n: std::vector< itkImageNBNIF33_Pointer >::size_type
        x: std::vector< itkImageNBNIF33_Pointer >::value_type const &

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33_insert(self, *args)

    def reserve(self, n):
        r"""
        reserve(self, n)

        Parameters
        ----------
        n: std::vector< itkImageNBNIF33_Pointer >::size_type

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33_reserve(self, n)

    def capacity(self):
        r"""capacity(self) -> std::vector< itkImageNBNIF33_Pointer >::size_type"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33_capacity(self)
    __swig_destroy__ = _itkSparseFieldFourthOrderLevelSetImageFilterPython.delete_vectoritkImageNBNIF33

# Register vectoritkImageNBNIF33 in _itkSparseFieldFourthOrderLevelSetImageFilterPython:
_itkSparseFieldFourthOrderLevelSetImageFilterPython.vectoritkImageNBNIF33_swigregister(vectoritkImageNBNIF33)

def itkImageNBNIF22_New():
    return itkImageNBNIF22.New()

class itkImageNBNIF22(itk.itkImagePython.itkImageBase2):
    r"""Proxy of C++ itkImageNBNIF22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkImageNBNIF22_Pointer"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkImageNBNIF22___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkImageNBNIF22_Pointer"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkImageNBNIF22_Clone(self)

    def Allocate(self, initializePixels=False):
        r"""
        Allocate(self, initializePixels=False)

        Parameters
        ----------
        initializePixels: bool

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkImageNBNIF22_Allocate(self, initializePixels)

    def FillBuffer(self, value):
        r"""
        FillBuffer(self, value)

        Parameters
        ----------
        value: itkNormalBandNodeIF2 *const &

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkImageNBNIF22_FillBuffer(self, value)

    def SetPixel(self, index, value):
        r"""
        SetPixel(self, index, value)

        Parameters
        ----------
        index: itkIndex2 const &
        value: itkNormalBandNodeIF2 *const &

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkImageNBNIF22_SetPixel(self, index, value)

    def GetPixel(self, *args):
        r"""
        GetPixel(self, index) -> itkNormalBandNodeIF2

        Parameters
        ----------
        index: itkIndex2 const &

        GetPixel(self, index) -> itkNormalBandNodeIF2 *&

        Parameters
        ----------
        index: itkIndex2 const &

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkImageNBNIF22_GetPixel(self, *args)

    def GetBufferPointer(self, *args):
        r"""
        GetBufferPointer(self) -> itkNormalBandNodeIF2
        GetBufferPointer(self) -> itkNormalBandNodeIF2 *const *
        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkImageNBNIF22_GetBufferPointer(self, *args)

    def GetPixelContainer(self, *args):
        r"""
        GetPixelContainer(self) -> itk::ImportImageContainer< unsigned long,itk::NormalBandNode< itk::Image< float > > * >
        GetPixelContainer(self) -> itk::ImportImageContainer< unsigned long,itk::NormalBandNode< itk::Image< float > > * > const *
        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkImageNBNIF22_GetPixelContainer(self, *args)

    def SetPixelContainer(self, container):
        r"""
        SetPixelContainer(self, container)

        Parameters
        ----------
        container: itk::ImportImageContainer< unsigned long,itk::NormalBandNode< itk::Image< float > > * > *

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkImageNBNIF22_SetPixelContainer(self, container)

    def Graft(self, image):
        r"""
        Graft(self, image)

        Parameters
        ----------
        image: itkImageNBNIF22 const *

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkImageNBNIF22_Graft(self, image)

    def GetPixelAccessor(self, *args):
        r"""
        GetPixelAccessor(self) -> itk::DefaultPixelAccessor< itk::NormalBandNode< itk::Image< float > > * >
        GetPixelAccessor(self) -> itk::DefaultPixelAccessor< itk::NormalBandNode< itk::Image< float > > * > const
        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkImageNBNIF22_GetPixelAccessor(self, *args)

    def GetNeighborhoodAccessor(self, *args):
        r"""
        GetNeighborhoodAccessor(self) -> itk::NeighborhoodAccessorFunctor< itk::Image< itk::NormalBandNode< itk::Image< float > > * > >
        GetNeighborhoodAccessor(self) -> itk::NeighborhoodAccessorFunctor< itk::Image< itk::NormalBandNode< itk::Image< float > > * > > const
        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkImageNBNIF22_GetNeighborhoodAccessor(self, *args)
    __swig_destroy__ = _itkSparseFieldFourthOrderLevelSetImageFilterPython.delete_itkImageNBNIF22

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageNBNIF22

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkImageNBNIF22_cast(obj)

    def __array__(self, dtype=None):
        import itk
        import numpy as np
        array = itk.array_from_image(self)
        return np.asarray(array, dtype=dtype)


    def New(*args, **kargs):
        """New() -> itkImageNBNIF22

        Create a new object of the class itkImageNBNIF22 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkImageNBNIF22.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkImageNBNIF22.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkImageNBNIF22.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkImageNBNIF22 in _itkSparseFieldFourthOrderLevelSetImageFilterPython:
_itkSparseFieldFourthOrderLevelSetImageFilterPython.itkImageNBNIF22_swigregister(itkImageNBNIF22)

def itkImageNBNIF33_New():
    return itkImageNBNIF33.New()

class itkImageNBNIF33(itk.itkImagePython.itkImageBase3):
    r"""Proxy of C++ itkImageNBNIF33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkImageNBNIF33_Pointer"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkImageNBNIF33___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkImageNBNIF33_Pointer"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkImageNBNIF33_Clone(self)

    def Allocate(self, initializePixels=False):
        r"""
        Allocate(self, initializePixels=False)

        Parameters
        ----------
        initializePixels: bool

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkImageNBNIF33_Allocate(self, initializePixels)

    def FillBuffer(self, value):
        r"""
        FillBuffer(self, value)

        Parameters
        ----------
        value: itkNormalBandNodeIF3 *const &

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkImageNBNIF33_FillBuffer(self, value)

    def SetPixel(self, index, value):
        r"""
        SetPixel(self, index, value)

        Parameters
        ----------
        index: itkIndex3 const &
        value: itkNormalBandNodeIF3 *const &

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkImageNBNIF33_SetPixel(self, index, value)

    def GetPixel(self, *args):
        r"""
        GetPixel(self, index) -> itkNormalBandNodeIF3

        Parameters
        ----------
        index: itkIndex3 const &

        GetPixel(self, index) -> itkNormalBandNodeIF3 *&

        Parameters
        ----------
        index: itkIndex3 const &

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkImageNBNIF33_GetPixel(self, *args)

    def GetBufferPointer(self, *args):
        r"""
        GetBufferPointer(self) -> itkNormalBandNodeIF3
        GetBufferPointer(self) -> itkNormalBandNodeIF3 *const *
        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkImageNBNIF33_GetBufferPointer(self, *args)

    def GetPixelContainer(self, *args):
        r"""
        GetPixelContainer(self) -> itk::ImportImageContainer< unsigned long,itk::NormalBandNode< itk::Image< float,3 > > * >
        GetPixelContainer(self) -> itk::ImportImageContainer< unsigned long,itk::NormalBandNode< itk::Image< float,3 > > * > const *
        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkImageNBNIF33_GetPixelContainer(self, *args)

    def SetPixelContainer(self, container):
        r"""
        SetPixelContainer(self, container)

        Parameters
        ----------
        container: itk::ImportImageContainer< unsigned long,itk::NormalBandNode< itk::Image< float,3 > > * > *

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkImageNBNIF33_SetPixelContainer(self, container)

    def Graft(self, image):
        r"""
        Graft(self, image)

        Parameters
        ----------
        image: itkImageNBNIF33 const *

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkImageNBNIF33_Graft(self, image)

    def GetPixelAccessor(self, *args):
        r"""
        GetPixelAccessor(self) -> itk::DefaultPixelAccessor< itk::NormalBandNode< itk::Image< float,3 > > * >
        GetPixelAccessor(self) -> itk::DefaultPixelAccessor< itk::NormalBandNode< itk::Image< float,3 > > * > const
        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkImageNBNIF33_GetPixelAccessor(self, *args)

    def GetNeighborhoodAccessor(self, *args):
        r"""
        GetNeighborhoodAccessor(self) -> itk::NeighborhoodAccessorFunctor< itk::Image< itk::NormalBandNode< itk::Image< float,3 > > *,3 > >
        GetNeighborhoodAccessor(self) -> itk::NeighborhoodAccessorFunctor< itk::Image< itk::NormalBandNode< itk::Image< float,3 > > *,3 > > const
        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkImageNBNIF33_GetNeighborhoodAccessor(self, *args)
    __swig_destroy__ = _itkSparseFieldFourthOrderLevelSetImageFilterPython.delete_itkImageNBNIF33

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageNBNIF33

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkImageNBNIF33_cast(obj)

    def __array__(self, dtype=None):
        import itk
        import numpy as np
        array = itk.array_from_image(self)
        return np.asarray(array, dtype=dtype)


    def New(*args, **kargs):
        """New() -> itkImageNBNIF33

        Create a new object of the class itkImageNBNIF33 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkImageNBNIF33.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkImageNBNIF33.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkImageNBNIF33.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkImageNBNIF33 in _itkSparseFieldFourthOrderLevelSetImageFilterPython:
_itkSparseFieldFourthOrderLevelSetImageFilterPython.itkImageNBNIF33_swigregister(itkImageNBNIF33)

def itkLevelSetFunctionWithRefitTermIF2SINBNIF22_New():
    return itkLevelSetFunctionWithRefitTermIF2SINBNIF22.New()

class itkLevelSetFunctionWithRefitTermIF2SINBNIF22(itk.itkLevelSetFunctionPython.itkLevelSetFunctionIF2):
    r"""Proxy of C++ itkLevelSetFunctionWithRefitTermIF2SINBNIF22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLevelSetFunctionWithRefitTermIF2SINBNIF22_Pointer"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkLevelSetFunctionWithRefitTermIF2SINBNIF22___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLevelSetFunctionWithRefitTermIF2SINBNIF22_Pointer"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkLevelSetFunctionWithRefitTermIF2SINBNIF22_Clone(self)

    def SetRefitWeight(self, w):
        r"""
        SetRefitWeight(self, w)

        Parameters
        ----------
        w: float const

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkLevelSetFunctionWithRefitTermIF2SINBNIF22_SetRefitWeight(self, w)

    def SetOtherPropagationWeight(self, w):
        r"""
        SetOtherPropagationWeight(self, w)

        Parameters
        ----------
        w: float const

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkLevelSetFunctionWithRefitTermIF2SINBNIF22_SetOtherPropagationWeight(self, w)

    def SetSparseTargetImage(self, im):
        r"""
        SetSparseTargetImage(self, im)

        Parameters
        ----------
        im: itkSparseImageNBNIF22 *

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkLevelSetFunctionWithRefitTermIF2SINBNIF22_SetSparseTargetImage(self, im)

    def GetSparseTargetImage(self):
        r"""GetSparseTargetImage(self) -> itkSparseImageNBNIF22"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkLevelSetFunctionWithRefitTermIF2SINBNIF22_GetSparseTargetImage(self)
    __swig_destroy__ = _itkSparseFieldFourthOrderLevelSetImageFilterPython.delete_itkLevelSetFunctionWithRefitTermIF2SINBNIF22

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLevelSetFunctionWithRefitTermIF2SINBNIF22

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkLevelSetFunctionWithRefitTermIF2SINBNIF22_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLevelSetFunctionWithRefitTermIF2SINBNIF22

        Create a new object of the class itkLevelSetFunctionWithRefitTermIF2SINBNIF22 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLevelSetFunctionWithRefitTermIF2SINBNIF22.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLevelSetFunctionWithRefitTermIF2SINBNIF22.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLevelSetFunctionWithRefitTermIF2SINBNIF22.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLevelSetFunctionWithRefitTermIF2SINBNIF22 in _itkSparseFieldFourthOrderLevelSetImageFilterPython:
_itkSparseFieldFourthOrderLevelSetImageFilterPython.itkLevelSetFunctionWithRefitTermIF2SINBNIF22_swigregister(itkLevelSetFunctionWithRefitTermIF2SINBNIF22)

def itkLevelSetFunctionWithRefitTermIF3SINBNIF33_New():
    return itkLevelSetFunctionWithRefitTermIF3SINBNIF33.New()

class itkLevelSetFunctionWithRefitTermIF3SINBNIF33(itk.itkLevelSetFunctionPython.itkLevelSetFunctionIF3):
    r"""Proxy of C++ itkLevelSetFunctionWithRefitTermIF3SINBNIF33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLevelSetFunctionWithRefitTermIF3SINBNIF33_Pointer"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkLevelSetFunctionWithRefitTermIF3SINBNIF33___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLevelSetFunctionWithRefitTermIF3SINBNIF33_Pointer"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkLevelSetFunctionWithRefitTermIF3SINBNIF33_Clone(self)

    def SetRefitWeight(self, w):
        r"""
        SetRefitWeight(self, w)

        Parameters
        ----------
        w: float const

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkLevelSetFunctionWithRefitTermIF3SINBNIF33_SetRefitWeight(self, w)

    def SetOtherPropagationWeight(self, w):
        r"""
        SetOtherPropagationWeight(self, w)

        Parameters
        ----------
        w: float const

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkLevelSetFunctionWithRefitTermIF3SINBNIF33_SetOtherPropagationWeight(self, w)

    def SetSparseTargetImage(self, im):
        r"""
        SetSparseTargetImage(self, im)

        Parameters
        ----------
        im: itkSparseImageNBNIF33 *

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkLevelSetFunctionWithRefitTermIF3SINBNIF33_SetSparseTargetImage(self, im)

    def GetSparseTargetImage(self):
        r"""GetSparseTargetImage(self) -> itkSparseImageNBNIF33"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkLevelSetFunctionWithRefitTermIF3SINBNIF33_GetSparseTargetImage(self)
    __swig_destroy__ = _itkSparseFieldFourthOrderLevelSetImageFilterPython.delete_itkLevelSetFunctionWithRefitTermIF3SINBNIF33

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLevelSetFunctionWithRefitTermIF3SINBNIF33

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkLevelSetFunctionWithRefitTermIF3SINBNIF33_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLevelSetFunctionWithRefitTermIF3SINBNIF33

        Create a new object of the class itkLevelSetFunctionWithRefitTermIF3SINBNIF33 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLevelSetFunctionWithRefitTermIF3SINBNIF33.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLevelSetFunctionWithRefitTermIF3SINBNIF33.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLevelSetFunctionWithRefitTermIF3SINBNIF33.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLevelSetFunctionWithRefitTermIF3SINBNIF33 in _itkSparseFieldFourthOrderLevelSetImageFilterPython:
_itkSparseFieldFourthOrderLevelSetImageFilterPython.itkLevelSetFunctionWithRefitTermIF3SINBNIF33_swigregister(itkLevelSetFunctionWithRefitTermIF3SINBNIF33)
class itkNormalBandNodeIF2(object):
    r"""Proxy of C++ itkNormalBandNodeIF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(self) -> itkNormalBandNodeIF2
        __init__(self, arg0) -> itkNormalBandNodeIF2

        Parameters
        ----------
        arg0: itkNormalBandNodeIF2 const &

        """
        _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkNormalBandNodeIF2_swiginit(self, _itkSparseFieldFourthOrderLevelSetImageFilterPython.new_itkNormalBandNodeIF2(*args))
    __swig_destroy__ = _itkSparseFieldFourthOrderLevelSetImageFilterPython.delete_itkNormalBandNodeIF2

# Register itkNormalBandNodeIF2 in _itkSparseFieldFourthOrderLevelSetImageFilterPython:
_itkSparseFieldFourthOrderLevelSetImageFilterPython.itkNormalBandNodeIF2_swigregister(itkNormalBandNodeIF2)
class itkNormalBandNodeIF3(object):
    r"""Proxy of C++ itkNormalBandNodeIF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(self) -> itkNormalBandNodeIF3
        __init__(self, arg0) -> itkNormalBandNodeIF3

        Parameters
        ----------
        arg0: itkNormalBandNodeIF3 const &

        """
        _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkNormalBandNodeIF3_swiginit(self, _itkSparseFieldFourthOrderLevelSetImageFilterPython.new_itkNormalBandNodeIF3(*args))
    __swig_destroy__ = _itkSparseFieldFourthOrderLevelSetImageFilterPython.delete_itkNormalBandNodeIF3

# Register itkNormalBandNodeIF3 in _itkSparseFieldFourthOrderLevelSetImageFilterPython:
_itkSparseFieldFourthOrderLevelSetImageFilterPython.itkNormalBandNodeIF3_swigregister(itkNormalBandNodeIF3)
class itkSparseFieldFourthOrderLevelSetImageFilterIF2IF2(itk.itkSparseFieldLevelSetImageFilterPython.itkSparseFieldLevelSetImageFilterIF2IF2):
    r"""Proxy of C++ itkSparseFieldFourthOrderLevelSetImageFilterIF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetMaxRefitIteration(self):
        r"""GetMaxRefitIteration(self) -> unsigned int const &"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF2IF2_GetMaxRefitIteration(self)

    def SetMaxRefitIteration(self, _arg):
        r"""
        SetMaxRefitIteration(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF2IF2_SetMaxRefitIteration(self, _arg)

    def GetMaxNormalIteration(self):
        r"""GetMaxNormalIteration(self) -> unsigned int const &"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF2IF2_GetMaxNormalIteration(self)

    def SetMaxNormalIteration(self, _arg):
        r"""
        SetMaxNormalIteration(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF2IF2_SetMaxNormalIteration(self, _arg)

    def GetCurvatureBandWidth(self):
        r"""GetCurvatureBandWidth(self) -> float const &"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF2IF2_GetCurvatureBandWidth(self)

    def SetCurvatureBandWidth(self, _arg):
        r"""
        SetCurvatureBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF2IF2_SetCurvatureBandWidth(self, _arg)

    def GetRMSChangeNormalProcessTrigger(self):
        r"""GetRMSChangeNormalProcessTrigger(self) -> float const &"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF2IF2_GetRMSChangeNormalProcessTrigger(self)

    def SetRMSChangeNormalProcessTrigger(self, _arg):
        r"""
        SetRMSChangeNormalProcessTrigger(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF2IF2_SetRMSChangeNormalProcessTrigger(self, _arg)

    def GetNormalProcessType(self):
        r"""GetNormalProcessType(self) -> int const &"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF2IF2_GetNormalProcessType(self)

    def SetNormalProcessType(self, _arg):
        r"""
        SetNormalProcessType(self, _arg)

        Parameters
        ----------
        _arg: int

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF2IF2_SetNormalProcessType(self, _arg)

    def GetNormalProcessConductance(self):
        r"""GetNormalProcessConductance(self) -> float const &"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF2IF2_GetNormalProcessConductance(self)

    def SetNormalProcessConductance(self, _arg):
        r"""
        SetNormalProcessConductance(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF2IF2_SetNormalProcessConductance(self, _arg)

    def SetNormalProcessUnsharpFlag(self, _arg):
        r"""
        SetNormalProcessUnsharpFlag(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF2IF2_SetNormalProcessUnsharpFlag(self, _arg)

    def GetNormalProcessUnsharpFlag(self):
        r"""GetNormalProcessUnsharpFlag(self) -> bool const &"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF2IF2_GetNormalProcessUnsharpFlag(self)

    def NormalProcessUnsharpFlagOn(self):
        r"""NormalProcessUnsharpFlagOn(self)"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF2IF2_NormalProcessUnsharpFlagOn(self)

    def NormalProcessUnsharpFlagOff(self):
        r"""NormalProcessUnsharpFlagOff(self)"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF2IF2_NormalProcessUnsharpFlagOff(self)

    def SetNormalProcessUnsharpWeight(self, _arg):
        r"""
        SetNormalProcessUnsharpWeight(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF2IF2_SetNormalProcessUnsharpWeight(self, _arg)

    def GetNormalProcessUnsharpWeight(self):
        r"""GetNormalProcessUnsharpWeight(self) -> float const &"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF2IF2_GetNormalProcessUnsharpWeight(self)

    def SetLevelSetFunction(self, lsf):
        r"""
        SetLevelSetFunction(self, lsf)

        Parameters
        ----------
        lsf: itkLevelSetFunctionWithRefitTermIF2SINBNIF22 *

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF2IF2_SetLevelSetFunction(self, lsf)

    def GetMinimumNumberOfLayers(self):
        r"""GetMinimumNumberOfLayers(self) -> unsigned int"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF2IF2_GetMinimumNumberOfLayers(self)

    def SetNumberOfLayers(self, n):
        r"""
        SetNumberOfLayers(self, n)

        Parameters
        ----------
        n: unsigned int const

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF2IF2_SetNumberOfLayers(self, n)

    def InitializeIteration(self):
        r"""InitializeIteration(self)"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF2IF2_InitializeIteration(self)
    OutputHasNumericTraitsCheck = _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF2IF2_OutputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkSparseFieldFourthOrderLevelSetImageFilterPython.delete_itkSparseFieldFourthOrderLevelSetImageFilterIF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkSparseFieldFourthOrderLevelSetImageFilterIF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF2IF2_cast(obj)

# Register itkSparseFieldFourthOrderLevelSetImageFilterIF2IF2 in _itkSparseFieldFourthOrderLevelSetImageFilterPython:
_itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF2IF2_swigregister(itkSparseFieldFourthOrderLevelSetImageFilterIF2IF2)
class itkSparseFieldFourthOrderLevelSetImageFilterIF3IF3(itk.itkSparseFieldLevelSetImageFilterPython.itkSparseFieldLevelSetImageFilterIF3IF3):
    r"""Proxy of C++ itkSparseFieldFourthOrderLevelSetImageFilterIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetMaxRefitIteration(self):
        r"""GetMaxRefitIteration(self) -> unsigned int const &"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF3IF3_GetMaxRefitIteration(self)

    def SetMaxRefitIteration(self, _arg):
        r"""
        SetMaxRefitIteration(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF3IF3_SetMaxRefitIteration(self, _arg)

    def GetMaxNormalIteration(self):
        r"""GetMaxNormalIteration(self) -> unsigned int const &"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF3IF3_GetMaxNormalIteration(self)

    def SetMaxNormalIteration(self, _arg):
        r"""
        SetMaxNormalIteration(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF3IF3_SetMaxNormalIteration(self, _arg)

    def GetCurvatureBandWidth(self):
        r"""GetCurvatureBandWidth(self) -> float const &"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF3IF3_GetCurvatureBandWidth(self)

    def SetCurvatureBandWidth(self, _arg):
        r"""
        SetCurvatureBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF3IF3_SetCurvatureBandWidth(self, _arg)

    def GetRMSChangeNormalProcessTrigger(self):
        r"""GetRMSChangeNormalProcessTrigger(self) -> float const &"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF3IF3_GetRMSChangeNormalProcessTrigger(self)

    def SetRMSChangeNormalProcessTrigger(self, _arg):
        r"""
        SetRMSChangeNormalProcessTrigger(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF3IF3_SetRMSChangeNormalProcessTrigger(self, _arg)

    def GetNormalProcessType(self):
        r"""GetNormalProcessType(self) -> int const &"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF3IF3_GetNormalProcessType(self)

    def SetNormalProcessType(self, _arg):
        r"""
        SetNormalProcessType(self, _arg)

        Parameters
        ----------
        _arg: int

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF3IF3_SetNormalProcessType(self, _arg)

    def GetNormalProcessConductance(self):
        r"""GetNormalProcessConductance(self) -> float const &"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF3IF3_GetNormalProcessConductance(self)

    def SetNormalProcessConductance(self, _arg):
        r"""
        SetNormalProcessConductance(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF3IF3_SetNormalProcessConductance(self, _arg)

    def SetNormalProcessUnsharpFlag(self, _arg):
        r"""
        SetNormalProcessUnsharpFlag(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF3IF3_SetNormalProcessUnsharpFlag(self, _arg)

    def GetNormalProcessUnsharpFlag(self):
        r"""GetNormalProcessUnsharpFlag(self) -> bool const &"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF3IF3_GetNormalProcessUnsharpFlag(self)

    def NormalProcessUnsharpFlagOn(self):
        r"""NormalProcessUnsharpFlagOn(self)"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF3IF3_NormalProcessUnsharpFlagOn(self)

    def NormalProcessUnsharpFlagOff(self):
        r"""NormalProcessUnsharpFlagOff(self)"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF3IF3_NormalProcessUnsharpFlagOff(self)

    def SetNormalProcessUnsharpWeight(self, _arg):
        r"""
        SetNormalProcessUnsharpWeight(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF3IF3_SetNormalProcessUnsharpWeight(self, _arg)

    def GetNormalProcessUnsharpWeight(self):
        r"""GetNormalProcessUnsharpWeight(self) -> float const &"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF3IF3_GetNormalProcessUnsharpWeight(self)

    def SetLevelSetFunction(self, lsf):
        r"""
        SetLevelSetFunction(self, lsf)

        Parameters
        ----------
        lsf: itkLevelSetFunctionWithRefitTermIF3SINBNIF33 *

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF3IF3_SetLevelSetFunction(self, lsf)

    def GetMinimumNumberOfLayers(self):
        r"""GetMinimumNumberOfLayers(self) -> unsigned int"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF3IF3_GetMinimumNumberOfLayers(self)

    def SetNumberOfLayers(self, n):
        r"""
        SetNumberOfLayers(self, n)

        Parameters
        ----------
        n: unsigned int const

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF3IF3_SetNumberOfLayers(self, n)

    def InitializeIteration(self):
        r"""InitializeIteration(self)"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF3IF3_InitializeIteration(self)
    OutputHasNumericTraitsCheck = _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF3IF3_OutputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkSparseFieldFourthOrderLevelSetImageFilterPython.delete_itkSparseFieldFourthOrderLevelSetImageFilterIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkSparseFieldFourthOrderLevelSetImageFilterIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF3IF3_cast(obj)

# Register itkSparseFieldFourthOrderLevelSetImageFilterIF3IF3 in _itkSparseFieldFourthOrderLevelSetImageFilterPython:
_itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldFourthOrderLevelSetImageFilterIF3IF3_swigregister(itkSparseFieldFourthOrderLevelSetImageFilterIF3IF3)

def itkSparseFieldLayerNBNIF2_New():
    return itkSparseFieldLayerNBNIF2.New()

class itkSparseFieldLayerNBNIF2(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkSparseFieldLayerNBNIF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkSparseFieldLayerNBNIF2_Pointer"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldLayerNBNIF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkSparseFieldLayerNBNIF2_Pointer"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldLayerNBNIF2_Clone(self)

    def Front(self, *args):
        r"""
        Front(self) -> itkNormalBandNodeIF2
        Front(self) -> itkNormalBandNodeIF2
        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldLayerNBNIF2_Front(self, *args)

    def PopFront(self):
        r"""PopFront(self)"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldLayerNBNIF2_PopFront(self)

    def PushFront(self, n):
        r"""
        PushFront(self, n)

        Parameters
        ----------
        n: itkNormalBandNodeIF2 *

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldLayerNBNIF2_PushFront(self, n)

    def Unlink(self, n):
        r"""
        Unlink(self, n)

        Parameters
        ----------
        n: itkNormalBandNodeIF2 *

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldLayerNBNIF2_Unlink(self, n)

    def Empty(self):
        r"""Empty(self) -> bool"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldLayerNBNIF2_Empty(self)

    def Size(self):
        r"""Size(self) -> unsigned int"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldLayerNBNIF2_Size(self)

    def SplitRegions(self, num):
        r"""
        SplitRegions(self, num) -> std::vector< itkSparseFieldLayerNBNIF2::RegionType,std::allocator< itkSparseFieldLayerNBNIF2::RegionType > >

        Parameters
        ----------
        num: int

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldLayerNBNIF2_SplitRegions(self, num)
    __swig_destroy__ = _itkSparseFieldFourthOrderLevelSetImageFilterPython.delete_itkSparseFieldLayerNBNIF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkSparseFieldLayerNBNIF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldLayerNBNIF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkSparseFieldLayerNBNIF2

        Create a new object of the class itkSparseFieldLayerNBNIF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkSparseFieldLayerNBNIF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkSparseFieldLayerNBNIF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkSparseFieldLayerNBNIF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkSparseFieldLayerNBNIF2 in _itkSparseFieldFourthOrderLevelSetImageFilterPython:
_itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldLayerNBNIF2_swigregister(itkSparseFieldLayerNBNIF2)

def itkSparseFieldLayerNBNIF3_New():
    return itkSparseFieldLayerNBNIF3.New()

class itkSparseFieldLayerNBNIF3(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkSparseFieldLayerNBNIF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkSparseFieldLayerNBNIF3_Pointer"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldLayerNBNIF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkSparseFieldLayerNBNIF3_Pointer"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldLayerNBNIF3_Clone(self)

    def Front(self, *args):
        r"""
        Front(self) -> itkNormalBandNodeIF3
        Front(self) -> itkNormalBandNodeIF3
        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldLayerNBNIF3_Front(self, *args)

    def PopFront(self):
        r"""PopFront(self)"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldLayerNBNIF3_PopFront(self)

    def PushFront(self, n):
        r"""
        PushFront(self, n)

        Parameters
        ----------
        n: itkNormalBandNodeIF3 *

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldLayerNBNIF3_PushFront(self, n)

    def Unlink(self, n):
        r"""
        Unlink(self, n)

        Parameters
        ----------
        n: itkNormalBandNodeIF3 *

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldLayerNBNIF3_Unlink(self, n)

    def Empty(self):
        r"""Empty(self) -> bool"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldLayerNBNIF3_Empty(self)

    def Size(self):
        r"""Size(self) -> unsigned int"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldLayerNBNIF3_Size(self)

    def SplitRegions(self, num):
        r"""
        SplitRegions(self, num) -> std::vector< itkSparseFieldLayerNBNIF3::RegionType,std::allocator< itkSparseFieldLayerNBNIF3::RegionType > >

        Parameters
        ----------
        num: int

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldLayerNBNIF3_SplitRegions(self, num)
    __swig_destroy__ = _itkSparseFieldFourthOrderLevelSetImageFilterPython.delete_itkSparseFieldLayerNBNIF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkSparseFieldLayerNBNIF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldLayerNBNIF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkSparseFieldLayerNBNIF3

        Create a new object of the class itkSparseFieldLayerNBNIF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkSparseFieldLayerNBNIF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkSparseFieldLayerNBNIF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkSparseFieldLayerNBNIF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkSparseFieldLayerNBNIF3 in _itkSparseFieldFourthOrderLevelSetImageFilterPython:
_itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseFieldLayerNBNIF3_swigregister(itkSparseFieldLayerNBNIF3)

def itkSparseImageNBNIF22_New():
    return itkSparseImageNBNIF22.New()

class itkSparseImageNBNIF22(itkImageNBNIF22):
    r"""Proxy of C++ itkSparseImageNBNIF22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkSparseImageNBNIF22_Pointer"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseImageNBNIF22___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkSparseImageNBNIF22_Pointer"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseImageNBNIF22_Clone(self)

    def GetNeighborhoodAccessor(self, *args):
        r"""
        GetNeighborhoodAccessor(self) -> itk::NeighborhoodAccessorFunctor< itk::SparseImage< itk::NormalBandNode< itk::Image< float > > > >
        GetNeighborhoodAccessor(self) -> itk::NeighborhoodAccessorFunctor< itk::SparseImage< itk::NormalBandNode< itk::Image< float > > > > const
        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseImageNBNIF22_GetNeighborhoodAccessor(self, *args)

    def AddNode(self, index):
        r"""
        AddNode(self, index) -> itkNormalBandNodeIF2

        Parameters
        ----------
        index: itkIndex2 const &

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseImageNBNIF22_AddNode(self, index)

    def GetNodeList(self):
        r"""GetNodeList(self) -> itkSparseFieldLayerNBNIF2"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseImageNBNIF22_GetNodeList(self)
    __swig_destroy__ = _itkSparseFieldFourthOrderLevelSetImageFilterPython.delete_itkSparseImageNBNIF22

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkSparseImageNBNIF22

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseImageNBNIF22_cast(obj)

    def New(*args, **kargs):
        """New() -> itkSparseImageNBNIF22

        Create a new object of the class itkSparseImageNBNIF22 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkSparseImageNBNIF22.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkSparseImageNBNIF22.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkSparseImageNBNIF22.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkSparseImageNBNIF22 in _itkSparseFieldFourthOrderLevelSetImageFilterPython:
_itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseImageNBNIF22_swigregister(itkSparseImageNBNIF22)

def itkSparseImageNBNIF33_New():
    return itkSparseImageNBNIF33.New()

class itkSparseImageNBNIF33(itkImageNBNIF33):
    r"""Proxy of C++ itkSparseImageNBNIF33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkSparseImageNBNIF33_Pointer"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseImageNBNIF33___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkSparseImageNBNIF33_Pointer"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseImageNBNIF33_Clone(self)

    def GetNeighborhoodAccessor(self, *args):
        r"""
        GetNeighborhoodAccessor(self) -> itk::NeighborhoodAccessorFunctor< itk::SparseImage< itk::NormalBandNode< itk::Image< float,3 > >,3 > >
        GetNeighborhoodAccessor(self) -> itk::NeighborhoodAccessorFunctor< itk::SparseImage< itk::NormalBandNode< itk::Image< float,3 > >,3 > > const
        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseImageNBNIF33_GetNeighborhoodAccessor(self, *args)

    def AddNode(self, index):
        r"""
        AddNode(self, index) -> itkNormalBandNodeIF3

        Parameters
        ----------
        index: itkIndex3 const &

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseImageNBNIF33_AddNode(self, index)

    def GetNodeList(self):
        r"""GetNodeList(self) -> itkSparseFieldLayerNBNIF3"""
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseImageNBNIF33_GetNodeList(self)
    __swig_destroy__ = _itkSparseFieldFourthOrderLevelSetImageFilterPython.delete_itkSparseImageNBNIF33

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkSparseImageNBNIF33

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseImageNBNIF33_cast(obj)

    def New(*args, **kargs):
        """New() -> itkSparseImageNBNIF33

        Create a new object of the class itkSparseImageNBNIF33 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkSparseImageNBNIF33.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkSparseImageNBNIF33.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkSparseImageNBNIF33.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkSparseImageNBNIF33 in _itkSparseFieldFourthOrderLevelSetImageFilterPython:
_itkSparseFieldFourthOrderLevelSetImageFilterPython.itkSparseImageNBNIF33_swigregister(itkSparseImageNBNIF33)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def sparse_field_fourth_order_level_set_image_filter(*args: itkt.ImageLike,  max_refit_iteration: int=..., max_normal_iteration: int=..., curvature_band_width: float=..., rms_change_normal_process_trigger: float=..., normal_process_type: int=..., normal_process_conductance: float=..., normal_process_unsharp_flag: bool=..., normal_process_unsharp_weight: float=..., level_set_function=..., number_of_layers: Union[int, int]=..., iso_surface_value: float=..., interpolate_surface_location: bool=..., difference_function=..., number_of_iterations: int=..., use_image_spacing: bool=..., maximum_rms_error: float=..., rms_change: float=..., manual_reinitialization: bool=..., is_initialized: bool=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for SparseFieldFourthOrderLevelSetImageFilter"""
    import itk

    kwarg_typehints = { 'max_refit_iteration':max_refit_iteration,'max_normal_iteration':max_normal_iteration,'curvature_band_width':curvature_band_width,'rms_change_normal_process_trigger':rms_change_normal_process_trigger,'normal_process_type':normal_process_type,'normal_process_conductance':normal_process_conductance,'normal_process_unsharp_flag':normal_process_unsharp_flag,'normal_process_unsharp_weight':normal_process_unsharp_weight,'level_set_function':level_set_function,'number_of_layers':number_of_layers,'iso_surface_value':iso_surface_value,'interpolate_surface_location':interpolate_surface_location,'difference_function':difference_function,'number_of_iterations':number_of_iterations,'use_image_spacing':use_image_spacing,'maximum_rms_error':maximum_rms_error,'rms_change':rms_change,'manual_reinitialization':manual_reinitialization,'is_initialized':is_initialized }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.SparseFieldFourthOrderLevelSetImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def sparse_field_fourth_order_level_set_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKLevelSets.SparseFieldFourthOrderLevelSetImageFilter
    sparse_field_fourth_order_level_set_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    sparse_field_fourth_order_level_set_image_filter.__doc__ = filter_object.__doc__



